Citation
-------------
If you use *swyft* in scientific publications, please include both of the following citations.

.. code-block:: bibtex

   @article{miller2021truncated,
      title={Truncated Marginal Neural Ratio Estimation},
      author={Miller, Benjamin Kurt and Cole, Alex and Forr{\'e}, Patrick and Louppe, Gilles and Weniger, Christoph},
      journal={Advances in Neural Information Processing Systems},
      volume={34},
      year={2021}
   }

   @article{miller2020simulation,
      title={Simulation-efficient marginal posterior estimation with swyft: stop wasting your precious time},
      author={Miller, Benjamin Kurt and Cole, Alex and Louppe, Gilles and Weniger, Christoph},
      journal={Machine Learning and the Physical Sciences: Workshop at the 34th Conference on Neural Information Processing Systems (NeurIPS)},
      year={2020}
   }
